# Kolibri-report

A package which report all your results from kolibri-ml
# Contents

```
├── README.md

```

- `README.md`: this documentation

## Install Homebrew

Follow [Neil Gee's guide](https://coolestguidesontheplanet.com/installing-homebrew-on-macos-sierra-package-manager-for-unix-apps) to install and set up homebrew for Mac OS Sierra

## Install Python 3

You can install Python 3 with Homebrew following the instructions from [The Hitchhiker's Guide to Python](http://python-guide-pt-br.readthedocs.io/en/latest/starting/install3/osx/) or following the very complete [Lisa Tagliaferri's guide](https://www.digitalocean.com/community/tutorials/how-to-install-python-3-and-set-up-a-local-programming-environment-on-macos).

Basically:

```bash
brew install python3
```

## Install kolibri-report

Now, you are ready to install `kolibri-report`:

```bash
pip3 install kolibri-report
```

Once you have installed Kolibri-reprot which automatically install all other dependecies.
